@@ -1,7 +1,5 @@
 #!/usr/bin/env perl
 
-# hjust and vjust
-
 use 5.016;
 use warnings;
 
@@ -28,7 +26,7 @@ my $df = Data::Frame->new(
 my $p = ggplot(
     data    => $df,
     mapping => aes( x => 'x', y => 'y', fill => 'z' )
-)->geom_raster( hjust => 0, vjust => 0 );
+)->geom_raster();
 
 if (defined $save_as) {
     $p->save($save_as);
